[![DOI](https://zenodo.org/badge/103197335.svg)](https://zenodo.org/badge/latestdoi/103197335)
[![Python 3.6](https://img.shields.io/badge/python-3.6-green.svg)](https://www.python.org/downloads/release/python-365/)
[![Build Status](https://ci.commonwl.org/buildStatus/icon?job=airflow-conformance)](https://ci.commonwl.org/job/airflow-conformance)


# **CWL-Airflow**

Python package to extend **[Apache-Airflow 1.10.3](https://github.com/apache/incubator-airflow)**
functionality with **[CWL v1.1](https://www.commonwl.org/v1.1/)** support.


## **Cite as**

Kotliar M; Kartashov AV; Barski A (2019): Supporting data for "CWL-Airflow: a lightweight pipeline manager supporting Common Workflow Language" GigaScience Database. http://dx.doi.org/10.5524/100618

## **Get the latest version**
```
pip install cwl-airflow
```
Latest version [documentation](https://cwl-airflow.readthedocs.io/en/latest/)


## **Get published version**
```
pip install cwl-airflow==1.0.16
```
Published version [documentation](https://cwl-airflow.readthedocs.io/en/1.0.18/)
